@@ -5,7 +5,6 @@ import random
 from qwilfish.constants import DEFAULT_START_SYMBOL
 from qwilfish.constants import DEFAULT_MIN_NONTERMINALS
 from qwilfish.constants import DEFAULT_MAX_NONTERMINALS
-from qwilfish.base_runner import BaseRunner
 from qwilfish.grammar import GrammarError
 from qwilfish.grammar import validate
 from qwilfish.grammar import nonterminals
@@ -29,7 +28,7 @@ class QwilFuzzer():
                  min_nonterminals=DEFAULT_MIN_NONTERMINALS,
                  max_nonterminals=DEFAULT_MAX_NONTERMINALS,
                  supported_opts=DEFAULT_OPTS,
-                 log=False):
+                 debug=False):
         self.grammar = grammar
         self.start_symbol = start_symbol
         self.min_nonterminals = min_nonterminals
@@ -40,15 +39,12 @@ class QwilFuzzer():
             for i in range(0, len(supported_opts)):
                 self.supported_opts |= {supported_opts[i]}
 
-        self.log=log
+        self.debug=debug
         self.check_grammar()
 
     def fuzz(self):
         self.derivation_tree = self.fuzz_tree()
-        return all_terminals(self.derivation_tree)
-
-    def run(self, runner=BaseRunner()):
-        return runner.run(self.fuzz())
+        return all_terminals(self.derivation_tree), self.derivation_tree
 
     def check_grammar(self):
         if self.start_symbol not in self.grammar:
@@ -77,13 +73,13 @@ class QwilFuzzer():
         return expansion_to_children(expansion)
 
     def expand_node_min_cost(self, node):
-        if self.log:
+        if self.debug:
             print("Expanding", all_terminals(node), "at minimum cost")
 
         return self.expand_node_by_cost(node, min)
 
     def expand_node_max_cost(self, node):
-        if self.log:
+        if self.debug:
             print("Expanding", all_terminals(node), "at maximum cost")
 
         return self.expand_node_by_cost(node, max)
@@ -94,7 +90,7 @@ class QwilFuzzer():
             raise DerivationTreeError("Unexpandable node, children: " +
                                       children)
 
-        if self.log:
+        if self.debug:
             print("Expanding", all_terminals(node), "randomly")
 
         expansions = self.grammar[symbol]
@@ -128,7 +124,7 @@ class QwilFuzzer():
 
         result = function()
 
-        if self.log:
+        if self.debug:
             print(repr(function) + "()", "=", repr(result))
 
         return self.apply_result(result, children)
@@ -145,7 +141,7 @@ class QwilFuzzer():
                     child_index = symbol_indexes[index]
                     if not isinstance(value, str):
                         value = repr(value)
-                    if self.log:
+                    if self.debug:
                         print("Replacing", all_terminals(
                             children[child_index]), "by", value)
 
@@ -158,7 +154,7 @@ class QwilFuzzer():
         elif isinstance(result, bool):
             pass
         else:
-            if self.log:
+            if self.debug:
                 print("Replacing", "".join(
                     [all_terminals(c) for c in children]), "by", result)
 
@@ -175,7 +171,7 @@ class QwilFuzzer():
         for children in children_alternatives:
             expansion = all_terminals((symbol, children))
             children_weight = probabilities[expansion]
-            if self.log:
+            if self.debug:
                 print(repr(expansion), "p =", children_weight)
             weights.append(children_weight)
 
@@ -250,7 +246,7 @@ class QwilFuzzer():
         if function is not None:
             result = self.eval_function(tree, function)
             if isinstance(result, bool) and not result:
-                if self.log:
+                if self.debug:
                     print(all_terminals(tree),
                         "did not satisfy", symbol, "constraint")
                 return False, children
@@ -297,7 +293,7 @@ class QwilFuzzer():
                 args.append(symbol_value)
 
         result = function(tree, *args)
-        if self.log:
+        if self.debug:
             print(repr(function) + repr(tuple(args)), "=", repr(result))
 
         return result
@@ -324,7 +320,7 @@ class QwilFuzzer():
                 or self.possible_expansions(tree) < limit)
                 and self.any_possible_expansions(tree)):
             tree = self.expand_tree_once(tree)
-            self.log_tree(tree)
+            self.debug_tree(tree)
 
         return tree
 
@@ -378,8 +374,8 @@ class QwilFuzzer():
 
         return sum(self.symbol_cost(s, seen) for s in symbols) + 1
 
-    def log_tree(self, tree):
-        if self.log:
+    def debug_tree(self, tree):
+        if self.debug:
             print("Tree:", all_terminals(tree))
 
     def expansion_probabilities(self, expansions, nonterminal="<symbol>"):
